# Module

[Tstickers Index](../README.md#tstickers-index) / [Tstickers](./index.md#tstickers) / Module

> Auto-generated documentation for [tstickers.__main__](../../../tstickers/__main__.py) module.
- [Module](#module)
